@@ -84,7 +84,7 @@ if (isModuleInstalled("IXR_Library") and getconfig("remote_api_enabled") and iss
             )))
                 return null;
             
-            return array_values(getAllSystemNames());
+            return array_values(getAllSlugs());
         }
 
         function languagesList($args)
@@ -135,7 +135,7 @@ if (isModuleInstalled("IXR_Library") and getconfig("remote_api_enabled") and iss
                 return null;
             
             $stat = array();
-            $stat["page_count"] = count(getAllSystemNames());
+            $stat["page_count"] = count(getAllSlugs());
             $stat["user_count"] = count(getUsers());
             $stat["homepage_title"] = getconfig("homepage_title");
             $stat["motto"] = getconfig("motto");
